API
===

.. currentmodule:: fastparquet

.. autosummary::
    ParquetFile
    ParquetFile.to_pandas
    ParquetFile.iter_row_groups
    ParquetFile.info
    write

.. autoclass:: ParquetFile
    :members: public_fn_with_sphinxy_docstring

.. automethod:: ParquetFile.to_pandas

.. automethod:: ParquetFile.iter_row_groups

.. autofunction:: write
